@@ -24,6 +24,7 @@
 #include "end_native.hpp"
 
 #include "native_conditional_unique_ptr.hpp"
+#include "native_unique_ptr.hpp"
 #include "Log.hpp"
 #include "ExceptionTypes.hpp"
 
@@ -79,12 +80,12 @@ namespace Apache
         /// <summary>
         /// Dispose: frees the internal buffer.
         /// </summary>
-        ~DataInput( ) { Cleanup( ); }
+        ~DataInput( ) { }
 
         /// <summary>
         /// Finalizer: frees the internal buffer.
         /// </summary>
-        !DataInput( ) { Cleanup( ); }      
+        !DataInput( ) { }
 
         /// <summary>
         /// Read a signed byte from the stream.
@@ -663,7 +664,7 @@ namespace Apache
           m_buffer = const_cast<System::Byte*>(nativeptr->currentBufferPosition());
           if ( m_buffer != NULL) {
             m_bufferLength = static_cast<decltype(m_bufferLength)>(nativeptr->getBytesRemaining());
-					}
+          }
           else {
             m_bufferLength = 0;
           }
@@ -691,14 +692,13 @@ namespace Apache
         bool m_isRootObjectPdx;
         Apache::Geode::Client::Cache^ m_cache;
         System::Byte* m_buffer;
+        native_unique_ptr<System::Byte[]>^ m_ownedBuffer;
         size_t m_bufferLength;
         size_t m_cursor;
         bool m_isManagedObject;
         array<Char>^ m_forStringDecode;
 
         native_conditional_unique_ptr<native::DataInput>^ m_nativeptr;
-      
-        void Cleanup( );
       };
     }  // namespace Client
   }  // namespace Geode
