@@ -135,17 +135,17 @@ std::shared_ptr<TallyWriter> regWriter;
 const char* myRegNames[] = {"DistRegionAck", "DistRegionNoAck", "ExampleRegion",
                             "SubRegion1", "SubRegion2"};
 void setCacheListener(const char* regName,
-                      std::shared_ptr<TallyListener> regListener) {
+                      std::shared_ptr<TallyListener> regionTallyListener) {
   auto reg = getHelper()->getRegion(regName);
   auto attrMutator = reg->getAttributesMutator();
-  attrMutator->setCacheListener(regListener);
+  attrMutator->setCacheListener(regionTallyListener);
 }
 
 void setCacheWriter(const char* regName,
-                    std::shared_ptr<TallyWriter> regWriter) {
+                    std::shared_ptr<TallyWriter> regionTallyWriter) {
   auto reg = getHelper()->getRegion(regName);
   auto attrMutator = reg->getAttributesMutator();
-  attrMutator->setCacheWriter(regWriter);
+  attrMutator->setCacheWriter(regionTallyWriter);
 }
 
 void validateEvents() {
