@@ -148,6 +148,7 @@ void initClientAuth(char UserType) {
     case 'A':
       credentialGeneratorHandler->getAllowedCredentialsForOps(ad, config,
                                                               nullptr);
+      break;
     default:
       break;
   }
@@ -464,14 +465,14 @@ DUNIT_TASK_DEFINITION(READER_CLIENT, StepThree)
     initClientAuth('R');
     std::shared_ptr<Region> rptr;
     char buf[100];
-    int i = 102;
+    int value = 102;
 
     createRegionForSecurity(regionNamesAuth[0], USE_ACK, true);
 
     rptr = getHelper()->getRegion(regionNamesAuth[0]);
-    sprintf(buf, "%s: %d", rptr->getName().c_str(), i);
+    sprintf(buf, "%s: %d", rptr->getName().c_str(), value);
     auto key = CacheableKey::create(buf);
-    sprintf(buf, "testUpdate::%s: value of %d", rptr->getName().c_str(), i);
+    sprintf(buf, "testUpdate::%s: value of %d", rptr->getName().c_str(), value);
     auto valuePtr = buf;
     try {
       LOG("Trying put Operation");
@@ -513,10 +514,8 @@ DUNIT_TASK_DEFINITION(READER_CLIENT, StepThree)
       auto checkPtr =
           std::dynamic_pointer_cast<CacheableString>(regPtr0->get(keyPtr));
       if (checkPtr != nullptr) {
-        char buf[1024];
-        sprintf(buf, "In net search, get returned %s for key %s",
-                checkPtr->value().c_str(), keys[2]);
-        LOG(buf);
+        LOG("In net search, get returned " + checkPtr->value() + " for key " +
+            keys[2]);
       } else {
         LOG("checkPtr is nullptr");
       }
@@ -635,7 +634,7 @@ DUNIT_TASK_DEFINITION(READER_CLIENT, StepThree)
 
     try {
       if (pool != nullptr) {
-        auto regPtr0 = getHelper()->getRegion(regionNamesAuth[0]);
+        regPtr0 = getHelper()->getRegion(regionNamesAuth[0]);
         FunctionService::onRegion(regPtr0).execute("securityTest")->getResult();
         FAIL("Function execution should not have completed successfully");
       } else {
