@@ -117,7 +117,10 @@ class MyCqListener : public CqListener {
       case CqOperation::OP_TYPE_DESTROY:
         m_numDeletes++;
         break;
-      default:
+      case CqOperation::OP_TYPE_INVALID:
+      case CqOperation::OP_TYPE_INVALIDATE:
+      case CqOperation::OP_TYPE_REGION_CLEAR:
+      case CqOperation::OP_TYPE_MARKER:
         break;
     }
     printf(" in create = %d, update = %d , delete = %d ", m_numInserts,
