@@ -36,30 +36,23 @@ using apache::geode::client::RegionShortcut;
 
 class SslOneWayTest : public ::testing::Test {
  protected:
-  // You can remove any or all of the following functions if their bodies would
-  // be empty.
-
   SslOneWayTest() {
-    // You can do set-up work for each test here.
     certificatePassword = std::string("apachegeode");
-    currentWorkingDirectory = boost::filesystem::current_path();
+    serverSslKeysDir = boost::filesystem::path(
+        getFrameworkString(FrameworkVariable::TestServerSslKeysDir));
+    clientSslKeysDir = boost::filesystem::path(
+        getFrameworkString(FrameworkVariable::TestClientSslKeysDir));
   }
 
   ~SslOneWayTest() override = default;
-  // You can do clean-up work that doesn't throw exceptions here.
 
-  // If the constructor and destructor are not enough for setting up
-  // and cleaning up each test, you can define the following methods:
   void SetUp() override {
-    // Code here will be called immediately after the constructor (right
-    // before each test).
     const auto clusterKeystore =
-        (currentWorkingDirectory /
-         boost::filesystem::path("ServerSslKeys/server_keystore_chained.p12"));
+        (serverSslKeysDir /
+         boost::filesystem::path("server_keystore_chained.p12"));
     const auto clusterTruststore =
-        (currentWorkingDirectory /
-         boost::filesystem::path(
-             "ServerSslKeys/server_truststore_chained_root.jks"));
+        (serverSslKeysDir /
+         boost::filesystem::path("server_truststore_chained_root.jks"));
 
     cluster.useSsl(false, clusterKeystore.string(), clusterTruststore.string(),
                    certificatePassword, certificatePassword);
@@ -74,23 +67,18 @@ class SslOneWayTest : public ::testing::Test {
         .execute();
   }
 
-  void TearDown() override {
-    // Code here will be called immediately after each test (right
-    // before the destructor).
-  }
+  void TearDown() override {}
 
-  // Class members declared here can be used by all tests in the test suite
-  // for Ssl.
   Cluster cluster = Cluster{LocatorCount{1}, ServerCount{1}};
   std::string certificatePassword;
-  boost::filesystem::path currentWorkingDirectory;
+  boost::filesystem::path serverSslKeysDir;
+  boost::filesystem::path clientSslKeysDir;
 };
 
 TEST_F(SslOneWayTest, PutGetWithValidSslConfiguration) {
   const auto clientTruststore =
-      (currentWorkingDirectory /
-       boost::filesystem::path(
-           "ClientSslKeys/client_truststore_chained_root.pem"));
+      (clientSslKeysDir /
+       boost::filesystem::path("client_truststore_chained_root.pem"));
   auto cache = CacheFactory()
                    .set("log-level", "DEBUG")
                    .set("ssl-enabled", "true")
@@ -113,9 +101,8 @@ TEST_F(SslOneWayTest, PutGetWithValidSslConfiguration) {
 
 TEST_F(SslOneWayTest, PutWithUntrustedTruststore) {
   const auto clientUntrustedTruststore =
-      (currentWorkingDirectory /
-       boost::filesystem::path(
-           "ClientSslKeys/client_truststore_untrusting.pem"));
+      (clientSslKeysDir /
+       boost::filesystem::path("client_truststore_untrusting.pem"));
 
   auto cache = CacheFactory()
                    .set("log-level", "none")
@@ -145,8 +132,8 @@ TEST_F(SslOneWayTest, PutWithUntrustedTruststore) {
 
 TEST_F(SslOneWayTest, PutWithCorruptTruststore) {
   const auto clientUntrustedTruststore =
-      (currentWorkingDirectory /
-       boost::filesystem::path("ClientSslKeys/client_truststore_corrupt.pem"));
+      (clientSslKeysDir /
+       boost::filesystem::path("client_truststore_corrupt.pem"));
 
   auto cache = CacheFactory()
                    .set("log-level", "none")
@@ -176,8 +163,8 @@ TEST_F(SslOneWayTest, PutWithCorruptTruststore) {
 
 TEST_F(SslOneWayTest, PutWithMissingTruststore) {
   const auto clientMissingTruststore =
-      (currentWorkingDirectory /
-       boost::filesystem::path("ClientSslKeys/client_truststore_missing.pem"));
+      (clientSslKeysDir /
+       boost::filesystem::path("client_truststore_missing.pem"));
 
   auto cache = CacheFactory()
                    .set("log-level", "none")
