@@ -36,30 +36,23 @@ using apache::geode::client::RegionShortcut;
 
 class SslTwoWayTest : public ::testing::Test {
  protected:
-  // You can remove any or all of the following functions if their bodies would
-  // be empty.
-
   SslTwoWayTest() {
-    // You can do set-up work for each test here.
     certificatePassword = std::string("apachegeode");
-    currentWorkingDirectory = boost::filesystem::current_path();
+    serverSslKeysDir = boost::filesystem::path(
+        getFrameworkString(FrameworkVariable::TestServerSslKeysDir));
+    clientSslKeysDir = boost::filesystem::path(
+        getFrameworkString(FrameworkVariable::TestClientSslKeysDir));
   }
 
   ~SslTwoWayTest() override = default;
-  // You can do clean-up work that doesn't throw exceptions here.
 
-  // If the constructor and destructor are not enough for setting up
-  // and cleaning up each test, you can define the following methods:
   void SetUp() override {
-    // Code here will be called immediately after the constructor (right
-    // before each test).
     const auto clusterKeystore =
-        (currentWorkingDirectory /
-         boost::filesystem::path("ServerSslKeys/server_keystore_chained.p12"));
+        (serverSslKeysDir /
+         boost::filesystem::path("server_keystore_chained.p12"));
     const auto clusterTruststore =
-        (currentWorkingDirectory /
-         boost::filesystem::path(
-             "ServerSslKeys/server_truststore_chained_root.jks"));
+        (serverSslKeysDir /
+         boost::filesystem::path("server_truststore_chained_root.jks"));
 
     cluster.useSsl(true, clusterKeystore.string(), clusterTruststore.string(),
                    certificatePassword, certificatePassword);
@@ -74,26 +67,21 @@ class SslTwoWayTest : public ::testing::Test {
         .execute();
   }
 
-  void TearDown() override {
-    // Code here will be called immediately after each test (right
-    // before the destructor).
-  }
+  void TearDown() override {}
 
-  // Class members declared here can be used by all tests in the test suite
-  // for Ssl.
   Cluster cluster = Cluster{LocatorCount{1}, ServerCount{1}};
   std::string certificatePassword;
-  boost::filesystem::path currentWorkingDirectory;
+  boost::filesystem::path serverSslKeysDir;
+  boost::filesystem::path clientSslKeysDir;
 };
 
 TEST_F(SslTwoWayTest, PutGetWithValidSslConfiguration) {
   const auto clientKeystore =
-      (currentWorkingDirectory /
-       boost::filesystem::path("ClientSslKeys/client_keystore_chained.pem"));
+      (clientSslKeysDir /
+       boost::filesystem::path("client_keystore_chained.pem"));
   const auto clientTruststore =
-      (currentWorkingDirectory /
-       boost::filesystem::path(
-           "ClientSslKeys/client_truststore_chained_root.pem"));
+      (clientSslKeysDir /
+       boost::filesystem::path("client_truststore_chained_root.pem"));
   auto cache = CacheFactory()
                    .set("log-level", "DEBUG")
                    .set("ssl-enabled", "true")
@@ -118,12 +106,11 @@ TEST_F(SslTwoWayTest, PutGetWithValidSslConfiguration) {
 
 TEST_F(SslTwoWayTest, PutWithInvalidKeystorePassword) {
   const auto clientKeystore =
-      (currentWorkingDirectory /
-       boost::filesystem::path("ClientSslKeys/client_keystore_chained.pem"));
+      (clientSslKeysDir /
+       boost::filesystem::path("client_keystore_chained.pem"));
   const auto clientTruststore =
-      (currentWorkingDirectory /
-       boost::filesystem::path(
-           "ClientSslKeys/client_truststore_chained_root.pem"));
+      (clientSslKeysDir /
+       boost::filesystem::path("client_truststore_chained_root.pem"));
   auto cache = CacheFactory()
                    .set("log-level", "none")
                    .set("ssl-enabled", "true")
@@ -154,12 +141,11 @@ TEST_F(SslTwoWayTest, PutWithInvalidKeystorePassword) {
 
 TEST_F(SslTwoWayTest, PutWithUntrustedKeystore) {
   const auto clientUntrustedKeystore =
-      (currentWorkingDirectory /
-       boost::filesystem::path("ClientSslKeys/client_keystore_untrusted.pem"));
+      (clientSslKeysDir /
+       boost::filesystem::path("client_keystore_untrusted.pem"));
   const auto clientTruststore =
-      (currentWorkingDirectory /
-       boost::filesystem::path(
-           "ClientSslKeys/client_truststore_chained_root.pem"));
+      (clientSslKeysDir /
+       boost::filesystem::path("client_truststore_chained_root.pem"));
 
   auto cache = CacheFactory()
                    .set("log-level", "none")
@@ -191,13 +177,12 @@ TEST_F(SslTwoWayTest, PutWithUntrustedKeystore) {
 
 TEST_F(SslTwoWayTest, PutWithCorruptKeystore) {
   const auto clientCorruptKeystore =
-      (currentWorkingDirectory /
-       boost::filesystem::path("ClientSslKeys/client_keystore_corrupt.pem"));
+      (clientSslKeysDir /
+       boost::filesystem::path("client_keystore_corrupt.pem"));
 
   const auto clientTruststore =
-      (currentWorkingDirectory /
-       boost::filesystem::path(
-           "ClientSslKeys/client_truststore_chained_root.pem"));
+      (clientSslKeysDir /
+       boost::filesystem::path("client_truststore_chained_root.pem"));
 
   auto cache = CacheFactory()
                    .set("log-level", "DEBUG")
@@ -229,12 +214,11 @@ TEST_F(SslTwoWayTest, PutWithCorruptKeystore) {
 
 TEST_F(SslTwoWayTest, PutWithUntrustedTruststore) {
   const auto clientKeystore =
-      (currentWorkingDirectory /
-       boost::filesystem::path("ClientSslKeys/client_keystore_chained.pem"));
+      (clientSslKeysDir /
+       boost::filesystem::path("client_keystore_chained.pem"));
   const auto clientUntrustedTruststore =
-      (currentWorkingDirectory /
-       boost::filesystem::path(
-           "ClientSslKeys/client_truststore_untrusting.pem"));
+      (clientSslKeysDir /
+       boost::filesystem::path("client_truststore_untrusting.pem"));
 
   auto cache = CacheFactory()
                    .set("log-level", "none")
@@ -266,11 +250,11 @@ TEST_F(SslTwoWayTest, PutWithUntrustedTruststore) {
 
 TEST_F(SslTwoWayTest, PutWithCorruptTruststore) {
   const auto clientKeystore =
-      (currentWorkingDirectory /
-       boost::filesystem::path("ClientSslKeys/client_keystore_chained.pem"));
+      (clientSslKeysDir /
+       boost::filesystem::path("client_keystore_chained.pem"));
   const auto clientUntrustedTruststore =
-      (currentWorkingDirectory /
-       boost::filesystem::path("ClientSslKeys/client_truststore_corrupt.pem"));
+      (clientSslKeysDir /
+       boost::filesystem::path("client_truststore_corrupt.pem"));
 
   auto cache = CacheFactory()
                    .set("log-level", "none")
@@ -302,11 +286,11 @@ TEST_F(SslTwoWayTest, PutWithCorruptTruststore) {
 
 TEST_F(SslTwoWayTest, PutWithMissingTruststore) {
   const auto clientKeystore =
-      (currentWorkingDirectory /
-       boost::filesystem::path("ClientSslKeys/client_keystore_chained.pem"));
+      (clientSslKeysDir /
+       boost::filesystem::path("client_keystore_chained.pem"));
   const auto clientMissingTruststore =
-      (currentWorkingDirectory /
-       boost::filesystem::path("ClientSslKeys/client_truststore_missing.pem"));
+      (clientSslKeysDir /
+       boost::filesystem::path("client_truststore_missing.pem"));
 
   auto cache = CacheFactory()
                    .set("log-level", "none")
