@@ -24,6 +24,7 @@
 #include <geode/RegionFactory.hpp>
 #include <geode/SystemProperties.hpp>
 
+#include "AdminRegion.hpp"
 #include "AutoDelete.hpp"
 #include "CacheXmlParser.hpp"
 #include "ClientProxyMembershipID.hpp"
@@ -494,7 +495,7 @@ std::shared_ptr<Region> CacheImpl::getRegion(const std::string& path) {
     }
   }
 
-  if (region && isPoolInMultiuserMode(region)) {
+  if (region && isPoolInMultiuserMode(*region)) {
     LOGWARN("Pool " + region->getAttributes().getPoolName() +
             " attached with region " + region->getFullPath() +
             " is in multiuser authentication mode. Operations may fail as "
@@ -640,13 +641,13 @@ void CacheImpl::readyForEvents() {
   }
 }
 
-bool CacheImpl::isPoolInMultiuserMode(std::shared_ptr<Region> regionPtr) {
-  const auto& poolName = regionPtr->getAttributes().getPoolName();
+bool CacheImpl::isPoolInMultiuserMode(const Region& region) const {
+  const auto& poolName = region.getAttributes().getPoolName();
 
   if (!poolName.empty()) {
-    auto poolPtr = regionPtr->getCache().getPoolManager().find(poolName);
-    if (poolPtr != nullptr && !poolPtr->isDestroyed()) {
-      return poolPtr->getMultiuserAuthentication();
+    auto pool = m_poolManager->find(poolName);
+    if (pool && !pool->isDestroyed()) {
+      return pool->getMultiuserAuthentication();
     }
   }
 
@@ -813,11 +814,11 @@ DataInput CacheImpl::createDataInput(const uint8_t* buffer, size_t len,
 }
 
 PdxInstanceFactory CacheImpl::createPdxInstanceFactory(
-    const std::string& className) const {
+    const std::string& className, bool expectDomainClass) const {
   this->throwIfClosed();
 
   return PdxInstanceFactory(
-      className, *m_cacheStats, *m_pdxTypeRegistry, *this,
+      className, expectDomainClass, *m_cacheStats, *m_pdxTypeRegistry, *this,
       m_distributedSystem.getSystemProperties().getEnableTimeStatistics());
 }
 
