@@ -202,6 +202,15 @@ std::shared_ptr<ClientMetadata> ClientMetadataService::SendClientPRMetadata(
   return nullptr;
 }
 
+void ClientMetadataService::removeBucketServerLocation(
+    const std::shared_ptr<BucketServerLocation>& serverLocation) {
+  boost::unique_lock<decltype(m_regionMetadataLock)> lock(m_regionMetadataLock);
+  for (const auto& regionMetadataIter : m_regionMetaDataMap) {
+    auto clientMetaData = regionMetadataIter.second;
+    clientMetaData->removeBucketServerLocation(serverLocation);
+  }
+}
+
 void ClientMetadataService::getBucketServerLocation(
     const std::shared_ptr<Region>& region,
     const std::shared_ptr<CacheableKey>& key,
@@ -398,35 +407,6 @@ ClientMetadataService::getServerToFilterMap(
   return serverToFilterMap;
 }
 
-void ClientMetadataService::markPrimaryBucketForTimeout(
-    const std::shared_ptr<Region>& region,
-    const std::shared_ptr<CacheableKey>& key,
-    const std::shared_ptr<Cacheable>& value,
-    const std::shared_ptr<Serializable>& aCallbackArgument, bool,
-    std::shared_ptr<BucketServerLocation>& serverLocation, int8_t& version) {
-  if (m_bucketWaitTimeout == std::chrono::milliseconds::zero()) return;
-
-  boost::unique_lock<decltype(m_PRbucketStatusLock)> lock(m_PRbucketStatusLock);
-
-  getBucketServerLocation(region, key, value, aCallbackArgument,
-                          false /*look for secondary host*/, serverLocation,
-                          version);
-
-  if (serverLocation && serverLocation->isValid()) {
-    LOGDEBUG("Server host and port are %s:%d",
-             serverLocation->getServerName().c_str(),
-             serverLocation->getPort());
-    int32_t bId = serverLocation->getBucketId();
-
-    const auto& bs = m_bucketStatus.find(region->getFullPath());
-
-    if (bs != m_bucketStatus.end()) {
-      bs->second->setBucketTimeout(bId);
-      LOGDEBUG("marking bucket %d as timeout ", bId);
-    }
-  }
-}
-
 std::shared_ptr<ClientMetadataService::BucketToKeysMap>
 ClientMetadataService::groupByBucketOnClientSide(
     const std::shared_ptr<Region>& region,
@@ -751,7 +731,8 @@ void ClientMetadataService::markPrimaryBucketForTimeoutButLookSecondaryBucket(
     std::shared_ptr<BucketServerLocation>& serverLocation, int8_t& version) {
   if (m_bucketWaitTimeout == std::chrono::milliseconds::zero()) return;
 
-  boost::unique_lock<decltype(m_PRbucketStatusLock)> lock(m_PRbucketStatusLock);
+  boost::unique_lock<decltype(m_PRbucketStatusLock)> boostPRbucketStatusLock(
+      m_PRbucketStatusLock);
 
   PRbuckets* prBuckets = nullptr;
   const auto& bs = m_bucketStatus.find(region->getFullPath());
@@ -766,7 +747,7 @@ void ClientMetadataService::markPrimaryBucketForTimeoutButLookSecondaryBucket(
 
   std::shared_ptr<ClientMetadata> cptr = nullptr;
   {
-    boost::shared_lock<decltype(m_regionMetadataLock)> lock(
+    boost::shared_lock<decltype(m_regionMetadataLock)> boostRegionMetadataLock(
         m_regionMetadataLock);
 
     const auto& cptrIter = m_regionMetaDataMap.find(region->getFullPath());
@@ -778,7 +759,6 @@ void ClientMetadataService::markPrimaryBucketForTimeoutButLookSecondaryBucket(
       return;
     }
   }
-
   LOGFINE("Setting in markPrimaryBucketForTimeoutButLookSecondaryBucket");
 
   auto totalBuckets = cptr->getTotalNumBuckets();
@@ -806,12 +786,8 @@ bool ClientMetadataService::isBucketMarkedForTimeout(const char* regionFullPath,
   const auto& bs = m_bucketStatus.find(regionFullPath);
   if (bs != m_bucketStatus.end()) {
     bool m = bs->second->isBucketTimedOut(bucketid, m_bucketWaitTimeout);
-    if (m) {
-      m_cache->incBlackListBucketTimeouts();
-    }
     LOGFINE("isBucketMarkedForTimeout:: for bucket %d returning = %d", bucketid,
             m);
-
     return m;
   }
 
