@@ -137,13 +137,6 @@ class ClientMetadataService {
       const std::vector<std::shared_ptr<CacheableKey>>& keys,
       const std::shared_ptr<Region>& region, bool isPrimary);
 
-  void markPrimaryBucketForTimeout(
-      const std::shared_ptr<Region>& region,
-      const std::shared_ptr<CacheableKey>& key,
-      const std::shared_ptr<Cacheable>& value,
-      const std::shared_ptr<Serializable>& aCallbackArgument, bool isPrimary,
-      std::shared_ptr<BucketServerLocation>& serverLocation, int8_t& version);
-
   void markPrimaryBucketForTimeoutButLookSecondaryBucket(
       const std::shared_ptr<Region>& region,
       const std::shared_ptr<CacheableKey>& key,
@@ -192,6 +185,9 @@ class ClientMetadataService {
       const std::shared_ptr<ClientMetadata>& metadata,
       const BucketSet& buckets);
 
+  void removeBucketServerLocation(
+      const std::shared_ptr<BucketServerLocation>& serverLocation);
+
  private:
   std::shared_ptr<ClientMetadata> SendClientPRMetadata(
       const char* regionPath, std::shared_ptr<ClientMetadata> cptr);
