@@ -45,9 +45,9 @@ class ClientProxyMembershipID : public DSMemberForVersionStamp {
   const std::string& getDSMemberId() const;
 
   ClientProxyMembershipID(std::string dsName, std::string randString,
-                          const char* hostname, const ACE_INET_Addr& address,
-                          uint32_t hostPort,
-                          const char* durableClientId = nullptr,
+                          const std::string& hostname,
+                          const ACE_INET_Addr& address, uint32_t hostPort,
+                          const std::string& durableClientId,
                           const std::chrono::seconds durableClientTimeOut =
                               std::chrono::seconds::zero());
 
@@ -77,8 +77,8 @@ class ClientProxyMembershipID : public DSMemberForVersionStamp {
 
   void initHostAddressVector(const uint8_t* hostAddr, uint32_t hostAddrLen);
 
-  void initObjectVars(const char* hostname, uint32_t hostPort,
-                      const char* durableClientId,
+  void initObjectVars(const std::string& hostname, uint32_t hostPort,
+                      const std::string& durableClientId,
                       const std::chrono::seconds durableClntTimeOut,
                       int32_t dcPort, int32_t vPID, int8_t vmkind,
                       int8_t splitBrainFlag, const char* dsname,
