@@ -33,14 +33,13 @@ class ClientProxyMembershipIDFactory {
   explicit ClientProxyMembershipIDFactory(std::string dsName);
 
   std::unique_ptr<ClientProxyMembershipID> create(
-      const char* hostname, const ACE_INET_Addr& address, uint32_t hostPort,
-      const char* durableClientId = nullptr,
+      const std::string& durableClientId = nullptr,
       const std::chrono::seconds durableClntTimeOut =
           std::chrono::seconds::zero());
 
  private:
-  std::string dsName;
-  std::string randString;
+  std::string dsName_;
+  std::string randString_;
 };
 
 }  // namespace client
