@@ -429,33 +429,20 @@ void ExecutionImpl::executeOnAllServers(const std::string& func,
   std::shared_ptr<CacheableString> exceptionPtr = nullptr;
   GfErrType err = tcrdm->sendRequestToAllServers(
       func.c_str(), getResult, timeout, m_args, m_rc, exceptionPtr);
-  if (exceptionPtr != nullptr && err != GF_NOERR) {
-    LOGDEBUG("Execute errorred: %d", err);
-    // throw FunctionExecutionException( "Execute: failed to execute function
-    // with server." );
-    if (err == GF_CACHESERVER_EXCEPTION) {
-      throw FunctionExecutionException(
-          "Execute: failed to execute function with server.");
-    } else {
-      throwExceptionIfError("Execute", err);
-    }
-  }
-
-  if (err == GF_AUTHENTICATION_FAILED_EXCEPTION ||
-      err == GF_NOT_AUTHORIZED_EXCEPTION ||
-      err == GF_AUTHENTICATION_REQUIRED_EXCEPTION) {
-    throwExceptionIfError("Execute", err);
-  }
 
   if (err != GF_NOERR) {
+    LOGDEBUG("Execute failed: %d", err);
     if (err == GF_CACHESERVER_EXCEPTION) {
-      auto message = std::string("Execute: exception at the server side: ") +
-                     exceptionPtr->value().c_str();
+      std::string message;
+      if (exceptionPtr) {
+        message = std::string("Execute: exception at the server side: ") +
+                  exceptionPtr->value().c_str();
+      } else {
+        message = "Execute: failed to execute function with server.";
+      }
       throw FunctionExecutionException(message);
     } else {
-      LOGDEBUG("Execute errorred with server exception: %d", err);
-      throw FunctionExecutionException(
-          "Execute: failed to execute function on servers.");
+      throwExceptionIfError("Execute", err);
     }
   }
 }
@@ -530,32 +517,6 @@ std::shared_ptr<CacheableVector> ExecutionImpl::executeOnPool(
         throwExceptionIfError("ExecuteOnPool:", err);
       }
     }
-    // auto values =
-    // resultCollector->getFunctionExecutionResults();
-    /*
-    ==25848== 1,610 (72 direct, 1,538 indirect) bytes in 2 blocks are definitely
-    lost in loss record 193 of 218
-    ==25848==    at 0x4007D75: operator new(unsigned int)
-    (vg_replace_malloc.c:313)
-    ==25848==    by 0x42B575A:
-    apache::geode::client::ExecutionImpl::executeOnPool(stlp_std::basic_string<char,
-    stlp_std::char_traits<char>, stlp_std::allocator<char> >&, unsigned char,
-    int, unsigned int) (ExecutionImpl.cpp:426)
-    ==25848==    by 0x42B65E6:
-    apache::geode::client::ExecutionImpl::execute(char const*,
-    bool, unsigned int, bool, bool, bool) (ExecutionImpl.cpp:292)
-    ==25848==    by 0x42B7897:
-    apache::geode::client::ExecutionImpl::execute(char const*,
-    bool, unsigned int, bool, bool) (ExecutionImpl.cpp:76)
-    ==25848==    by 0x8081320: Task_Client1OpTest::doTask() (in
-    /export/pnq-gst-dev01a/users/adongre/cedar_dev_Nov12/build-artifacts/linux/tests/cppcache/testThinClientPoolExecuteFunctionPrSHOP)
-    ==25848==    by 0x808D5CA: dunit::TestSlave::begin() (in
-    /export/pnq-gst-dev01a/users/adongre/cedar_dev_Nov12/build-artifacts/linux/tests/cppcache/testThinClientPoolExecuteFunctionPrSHOP)
-    ==25848==    by 0x8089807: dunit::dmain(int, char**) (in
-    /export/pnq-gst-dev01a/users/adongre/cedar_dev_Nov12/build-artifacts/linux/tests/cppcache/testThinClientPoolExecuteFunctionPrSHOP)
-    ==25848==    by 0x805F9EA: main (in
-    /export/pnq-gst-dev01a/users/adongre/cedar_dev_Nov12/build-artifacts/linux/tests/cppcache/testThinClientPoolExecuteFunctionPrSHOP)
-    */
     return nullptr;
   }
   return nullptr;
