@@ -63,29 +63,27 @@ namespace geode {
 namespace log {
 namespace globals {
 
-std::string* g_logFile = nullptr;
-std::string* g_logFileWithExt = nullptr;
+static std::string* g_logFile = nullptr;
+static std::string* g_logFileWithExt = nullptr;
 
-size_t g_bytesWritten = 0;
-bool g_isLogFileOpened = false;
+static size_t g_bytesWritten = 0;
+static bool g_isLogFileOpened = false;
 
-size_t g_fileSizeLimit = GEODE_MAX_LOG_FILE_LIMIT;
-size_t g_diskSpaceLimit = GEODE_MAX_LOG_DISK_LIMIT;
+static size_t g_fileSizeLimit = GEODE_MAX_LOG_FILE_LIMIT;
+static size_t g_diskSpaceLimit = GEODE_MAX_LOG_DISK_LIMIT;
 
-char g_logFileNameBuffer[2048] = {0};
+static std::mutex g_logMutex;
 
-std::mutex g_logMutex;
-
-int g_rollIndex = 0;
-size_t g_spaceUsed = 0;
+static int g_rollIndex = 0;
+static size_t g_spaceUsed = 0;
 // Make a pair for the filename & its size
-std::pair<std::string, int64_t> g_fileInfoPair;
+static std::pair<std::string, int64_t> g_fileInfoPair;
 // Vector to hold the fileInformation
 typedef std::vector<std::pair<std::string, int64_t> > g_fileInfo;
 
-FILE* g_log = nullptr;
-ACE_utsname g_uname;
-pid_t g_pid = 0;
+static FILE* g_log = nullptr;
+static ACE_utsname g_uname;
+static pid_t g_pid = 0;
 
 }  // namespace globals
 }  // namespace log
@@ -213,8 +211,8 @@ void Log::init(LogLevel level, const char* logFileName, int32_t logFileLimit,
     // Appending a ".log" at the end if it does not exist or file has some other
     // extension.
     std::string filebasename = ACE::basename(g_logFile->c_str());
-    int32_t len = static_cast<int32_t>(filebasename.length());
-    size_t fileExtPos = filebasename.find_last_of('.', len);
+    auto len = static_cast<int32_t>(filebasename.length());
+    auto fileExtPos = filebasename.find_last_of('.', len);
     // if no extension then add .log extension
     if (fileExtPos == std::string::npos) {
       g_logFileWithExt = new std::string(*g_logFile + ".log");
@@ -257,7 +255,7 @@ void Log::init(LogLevel level, const char* logFileName, int32_t logFileLimit,
     if (status != -1) {
       for (int index = 0; index < sds.length(); ++index) {
         std::string strname = ACE::basename(sds[index]->d_name);
-        size_t fileExtPos = strname.find_last_of('.', strname.length());
+        fileExtPos = strname.find_last_of('.', strname.length());
         if (fileExtPos != std::string::npos) {
           std::string tempname = strname.substr(0, fileExtPos);
           size_t fileHyphenPos = tempname.find_last_of('-', tempname.length());
@@ -280,7 +278,7 @@ void Log::init(LogLevel level, const char* logFileName, int32_t logFileLimit,
       std::string extName;
       std::string newfilestr;
 
-      int32_t len = static_cast<int32_t>(g_logFileWithExt->length());
+      len = static_cast<int32_t>(g_logFileWithExt->length());
       int32_t lastPosOfSep = static_cast<int32_t>(
           g_logFileWithExt->find_last_of(ACE_DIRECTORY_SEPARATOR_CHAR, len));
       if (lastPosOfSep == -1) {
@@ -464,14 +462,10 @@ const char* Log::levelToChars(LogLevel level) {
 
     case LogLevel::All:
       return "all";
-
-    default: {
-      char buf[64] = {0};
-      std::snprintf(buf, 64, "Unexpected log level: %d",
-                    static_cast<int>(level));
-      throw IllegalArgumentException(buf);
-    }
   }
+  char buf[64] = {0};
+  std::snprintf(buf, 64, "Unexpected log level: %d", static_cast<int>(level));
+  throw IllegalArgumentException(buf);
 }
 
 LogLevel Log::charsToLevel(const std::string& chars) {
@@ -567,7 +561,7 @@ void Log::put(LogLevel level, const char* msg) {
     }
 
     formatLogLine(buf, level);
-    size_t numChars = static_cast<int>(std::strlen(buf) + std::strlen(msg));
+    auto numChars = static_cast<int>(std::strlen(buf) + std::strlen(msg));
     g_bytesWritten +=
         numChars + 2;  // bcoz we have to count trailing new line (\n)
 
@@ -657,7 +651,7 @@ void Log::put(LogLevel level, const char* msg) {
           char printmsg[256];
           std::snprintf(printmsg, 256, "%s\t%s\n", "Could not delete",
                         fileInfo[fileIndex].first.c_str());
-          int numChars =
+          numChars =
               fprintf(g_log, "%s%s\n", formatLogLine(buf, level), printmsg);
           g_bytesWritten +=
               numChars + 2;  // bcoz we have to count trailing new line (\n)
