@@ -41,7 +41,8 @@ PdxType::~PdxType() noexcept {
 }
 
 PdxType::PdxType(PdxTypeRegistry& pdxTypeRegistry,
-                 const std::string& pdxDomainClassName, bool isLocal)
+                 const std::string& pdxDomainClassName, bool isLocal,
+                 bool expectDomainClass)
     : Serializable(),
       m_pdxFieldTypes(new std::vector<std::shared_ptr<PdxFieldType>>()),
       m_className(pdxDomainClassName),
@@ -53,9 +54,13 @@ PdxType::PdxType(PdxTypeRegistry& pdxTypeRegistry,
       m_isVarLenFieldAdded(false),
       m_remoteToLocalFieldMap(nullptr),
       m_localToRemoteFieldMap(nullptr),
-      m_noJavaClass(false),
+      is_java_class_(expectDomainClass),
       m_pdxTypeRegistry(pdxTypeRegistry) {}
 
+PdxType::PdxType(PdxTypeRegistry& pdxTypeRegistry,
+                 const std::string& pdxDomainClassName, bool isLocal)
+    : PdxType(pdxTypeRegistry, pdxDomainClassName, isLocal, true) {}
+
 void PdxType::toData(DataOutput& output) const {
   output.write(static_cast<int8_t>(DSCode::DataSerializable));  // 45
   output.write(static_cast<int8_t>(DSCode::Class));             // 43
@@ -65,7 +70,7 @@ void PdxType::toData(DataOutput& output) const {
   output.writeString(m_className);
 
   // m_noJavaClass
-  output.writeBoolean(m_noJavaClass);
+  output.writeBoolean(!is_java_class_);
 
   // m_geodeTypeId
   output.writeInt(m_geodeTypeId);
@@ -90,7 +95,7 @@ void PdxType::fromData(DataInput& input) {
 
   m_className = input.readString();
 
-  m_noJavaClass = input.readBoolean();
+  is_java_class_ = !input.readBoolean();
 
   m_geodeTypeId = input.readInt32();
 
@@ -537,33 +542,32 @@ void PdxType::generatePositionMap() {
   }
 }
 
-bool PdxType::Equals(std::shared_ptr<PdxType> otherObj) {
-  if (otherObj == nullptr) return false;
+bool PdxType::operator==(const PdxType& other) const {
+  if (this->m_className != other.m_className) {
+    return false;
+  }
 
-  PdxType* ot = dynamic_cast<PdxType*>(otherObj.get());
+  if (this->is_java_class_ != other.is_java_class_) {
+    return false;
+  }
 
-  if (ot == nullptr) return false;
+  if (this->getTotalFields() != other.getTotalFields()) {
+    return false;
+  }
 
-  if (ot == this) return true;
-
-  if (ot->m_pdxFieldTypes->size() != m_pdxFieldTypes->size()) return false;
-
-  for (uint32_t i = 0; i < m_pdxFieldTypes->size(); i++) {
-    if (!ot->m_pdxFieldTypes->at(i)->equals(m_pdxFieldTypes->at(i))) {
+  auto thisIt = this->m_fieldNameVsPdxType.begin();
+  auto otherIt = other.m_fieldNameVsPdxType.begin();
+  for (; thisIt != this->m_fieldNameVsPdxType.end(); thisIt++, otherIt++) {
+    auto thisEntry = *thisIt;
+    auto otherEntry = *otherIt;
+    if (thisEntry.first != otherEntry.first ||
+        *(thisEntry.second) != *(otherEntry.second)) {
       return false;
     }
   }
   return true;
 }
 
-bool PdxType::operator<(const PdxType& other) const {
-  auto typeIdLessThan = this->m_geodeTypeId < other.m_geodeTypeId;
-  auto typeIdsBothZero =
-      (this->m_geodeTypeId == 0) && (other.m_geodeTypeId == 0);
-  auto classnameLessThan = this->m_className < other.m_className;
-  return (typeIdLessThan || (typeIdsBothZero && classnameLessThan));
-}
-
 }  // namespace client
 }  // namespace geode
 }  // namespace apache
