@@ -163,21 +163,13 @@ bool TcrConnection::initTcrConnection(
         reinterpret_cast<const uint8_t*>(dsMemberId.c_str()),
         static_cast<int32_t>(dsMemberId.size()));
   } else {
-    ACE_TCHAR hostName[256];
-    ACE_OS::hostname(hostName, sizeof(hostName) - 1);
-
-    ACE_INET_Addr driver(hostName);
-
-    uint16_t hostPort = 0;
-
     // Add 3 durable Subcription properties to ClientProxyMembershipID
-
     auto&& durableId = sysProp.durableClientId();
     auto&& durableTimeOut = sysProp.durableTimeout();
 
     // Write ClientProxyMembershipID serialized object.
     auto memId = cacheImpl->getClientProxyMembershipIDFactory().create(
-        hostName, driver, hostPort, durableId.c_str(), durableTimeOut);
+        durableId.c_str(), durableTimeOut);
     const auto& dsMemberId = memId->getDSMemberId();
     handShakeMsg.writeBytes(
         reinterpret_cast<const uint8_t*>(dsMemberId.c_str()),
@@ -433,19 +425,28 @@ bool TcrConnection::initTcrConnection(
 }
 
 Connector* TcrConnection::createConnection(
-    const char* endpoint, std::chrono::microseconds connectTimeout,
+    const std::string& address, std::chrono::microseconds connectTimeout,
     int32_t maxBuffSizePool) {
   Connector* socket = nullptr;
   auto& systemProperties = m_connectionManager->getCacheImpl()
                                ->getDistributedSystem()
                                .getSystemProperties();
   if (systemProperties.sslEnabled()) {
-    socket = new TcpSslConn(endpoint, connectTimeout, maxBuffSizePool,
-                            systemProperties.sslTrustStore().c_str(),
-                            systemProperties.sslKeyStore().c_str(),
-                            systemProperties.sslKeystorePassword().c_str());
+    const auto& sniHostname = m_poolDM->getSniProxyHost();
+    if (sniHostname.empty()) {
+      socket = new TcpSslConn(address, connectTimeout, maxBuffSizePool,
+                              systemProperties.sslTrustStore(),
+                              systemProperties.sslKeyStore(),
+                              systemProperties.sslKeystorePassword());
+    } else {
+      const auto sniPort = m_poolDM->getSniProxyPort();
+      socket = new TcpSslConn(
+          address, connectTimeout, maxBuffSizePool, sniHostname, sniPort,
+          systemProperties.sslTrustStore(), systemProperties.sslKeyStore(),
+          systemProperties.sslKeystorePassword());
+    }
   } else {
-    socket = new TcpConn(endpoint, connectTimeout, maxBuffSizePool);
+    socket = new TcpConn(address, connectTimeout, maxBuffSizePool);
   }
   // as socket.init() calls throws exception...
   m_conn = socket;
@@ -522,7 +523,8 @@ inline ConnErrType TcrConnection::sendData(
   std::chrono::microseconds defaultWaitSecs = std::chrono::seconds(2);
   if (defaultWaitSecs > sendTimeout) defaultWaitSecs = sendTimeout;
   LOGDEBUG(
-      "before send len %zu sendTimeoutSec = %s checkConnected = %d m_connected "
+      "before send len %zu sendTimeoutSec = %s checkConnected = %d "
+      "m_connected "
       "%d",
       length, to_string(sendTimeout).c_str(), checkConnected, m_connected);
   while (length > 0 && sendTimeout > std::chrono::microseconds::zero()) {
@@ -688,9 +690,8 @@ char* TcrConnection::readMessage(size_t* recvLen,
   ConnErrType error;
 
   std::chrono::microseconds headerTimeout = receiveTimeoutSec;
-  if (doHeaderTimeoutRetries &&
-      receiveTimeoutSec == DEFAULT_READ_TIMEOUT_SECS) {
-    headerTimeout = DEFAULT_READ_TIMEOUT_SECS * DEFAULT_TIMEOUT_RETRIES;
+  if (doHeaderTimeoutRetries && receiveTimeoutSec == DEFAULT_READ_TIMEOUT) {
+    headerTimeout = DEFAULT_READ_TIMEOUT * DEFAULT_TIMEOUT_RETRIES;
   }
 
   LOGDEBUG("TcrConnection::readMessage: receiving reply from endpoint %s",
@@ -839,7 +840,7 @@ void TcrConnection::readMessageChunked(TcrMessageReply& reply,
 std::chrono::microseconds TcrConnection::calculateHeaderTimeout(
     std::chrono::microseconds receiveTimeout, bool retry) {
   auto headerTimeout = receiveTimeout;
-  if (retry && receiveTimeout == DEFAULT_READ_TIMEOUT_SECS) {
+  if (retry && receiveTimeout == DEFAULT_READ_TIMEOUT) {
     headerTimeout *= DEFAULT_TIMEOUT_RETRIES;
   }
   return headerTimeout;
@@ -1190,7 +1191,56 @@ std::shared_ptr<CacheableString> TcrConnection::readHandshakeString(
 
       break;
     }
-    default: {
+    case DSCode::FixedIDDefault:
+    case DSCode::FixedIDByte:
+    case DSCode::FixedIDInt:
+    case DSCode::FixedIDNone:
+    case DSCode::FixedIDShort:
+    case DSCode::CacheableLinkedList:
+    case DSCode::Properties:
+    case DSCode::PdxType:
+    case DSCode::BooleanArray:
+    case DSCode::CharArray:
+    case DSCode::NullObj:
+    case DSCode::CacheableString:
+    case DSCode::Class:
+    case DSCode::JavaSerializable:
+    case DSCode::DataSerializable:
+    case DSCode::CacheableBytes:
+    case DSCode::CacheableInt16Array:
+    case DSCode::CacheableInt32Array:
+    case DSCode::CacheableInt64Array:
+    case DSCode::CacheableFloatArray:
+    case DSCode::CacheableDoubleArray:
+    case DSCode::CacheableObjectArray:
+    case DSCode::CacheableBoolean:
+    case DSCode::CacheableCharacter:
+    case DSCode::CacheableByte:
+    case DSCode::CacheableInt16:
+    case DSCode::CacheableInt32:
+    case DSCode::CacheableInt64:
+    case DSCode::CacheableFloat:
+    case DSCode::CacheableDouble:
+    case DSCode::CacheableDate:
+    case DSCode::CacheableFileName:
+    case DSCode::CacheableStringArray:
+    case DSCode::CacheableArrayList:
+    case DSCode::CacheableHashSet:
+    case DSCode::CacheableHashMap:
+    case DSCode::CacheableTimeUnit:
+    case DSCode::CacheableHashTable:
+    case DSCode::CacheableVector:
+    case DSCode::CacheableIdentityHashMap:
+    case DSCode::CacheableLinkedHashSet:
+    case DSCode::CacheableStack:
+    case DSCode::CacheableASCIIStringHuge:
+    case DSCode::CacheableStringHuge:
+    case DSCode::InternalDistributedMember:
+    case DSCode::CacheableEnum:
+    case DSCode::ClientProxyMembershipId:
+    case DSCode::CacheableUserData:
+    case DSCode::CacheableUserData4:
+    case DSCode::PDX: {
       GF_SAFE_DELETE_CON(m_conn);
       throwException(
           GeodeIOException("TcrConnection::TcrConnection: "
