@@ -91,7 +91,7 @@ class TcrEndpoint;
 class SystemProperties;
 class ThinClientPoolDM;
 class TcrConnectionManager;
-class APACHE_GEODE_EXPORT TcrConnection {
+class TcrConnection {
  public:
   using clock = std::chrono::steady_clock;
   using time_point = clock::time_point;
@@ -118,7 +118,6 @@ class APACHE_GEODE_EXPORT TcrConnection {
    *    read one byte from server, it should be CLIENT_TO_SERVER
    *    Otherwise, construction fails.
    * @param     ports     List of local ports for connections to endpoint
-   * @param     numPorts  Size of ports list
    */
   bool initTcrConnection(
       TcrEndpoint* endpointObj, const char* endpoint,
@@ -193,17 +192,17 @@ class APACHE_GEODE_EXPORT TcrConnection {
   char* sendRequest(
       const char* buffer, size_t len, size_t* recvLen,
       std::chrono::microseconds sendTimeoutSec = DEFAULT_WRITE_TIMEOUT,
-      std::chrono::microseconds receiveTimeoutSec = DEFAULT_READ_TIMEOUT_SECS,
+      std::chrono::microseconds receiveTimeoutSec = DEFAULT_READ_TIMEOUT,
       int32_t request = -1);
 
   /**
    * send a synchronized request to server for REGISTER_INTEREST_LIST.
    *
-   * @param      buffer the buffer to send
-   *             len length of the data to send
-   *             message vector, which will return chunked TcrMessage.
-   *             sendTimeoutSec write timeout in sec
-   *             receiveTimeoutSec read timeout in sec
+   * @param      request the buffer to send
+   * @param      len length of the data to send
+   * @param      message vector, which will return chunked TcrMessage.
+   * @param      sendTimeoutSec write timeout in sec
+   * @param      receiveTimeoutSec read timeout in sec
    * @exception  GeodeIOException  if an I/O error occurs (socket failure).
    * @exception  TimeoutException  if timeout happens at any of the 3 socket
    * operation: 1 write, 2 read
@@ -211,16 +210,15 @@ class APACHE_GEODE_EXPORT TcrConnection {
   void sendRequestForChunkedResponse(
       const TcrMessage& request, size_t len, TcrMessageReply& message,
       std::chrono::microseconds sendTimeoutSec = DEFAULT_WRITE_TIMEOUT,
-      std::chrono::microseconds receiveTimeoutSec = DEFAULT_READ_TIMEOUT_SECS);
+      std::chrono::microseconds receiveTimeoutSec = DEFAULT_READ_TIMEOUT);
 
   /**
    * send an asynchronized request to server. No response is expected.
    * we need to use it to send CLOSE_CONNECTION msg
    *
    * @param      buffer the buffer to send
-   *             len length of the data to send
-   *             sendTimeoutSec write timeout in sec
-   * @return     no return. Because it either succeeds, or throw exception.
+   * @param      len length of the data to send
+   * @param      sendTimeoutSec write timeout in sec
    * @exception  GeodeIOException  if an I/O error occurs (socket failure).
    * @exception  TimeoutException  if timeout happens at any of the 3 socket
    * operation: 1 write, 2 read
@@ -247,7 +245,7 @@ class APACHE_GEODE_EXPORT TcrConnection {
    */
   char* receive(
       size_t* recvLen, ConnErrType* opErr,
-      std::chrono::microseconds receiveTimeoutSec = DEFAULT_READ_TIMEOUT_SECS);
+      std::chrono::microseconds receiveTimeoutSec = DEFAULT_READ_TIMEOUT);
 
   //  readMessage is now public
   /**
@@ -367,7 +365,7 @@ class APACHE_GEODE_EXPORT TcrConnection {
 
   /** Create a normal or SSL connection */
   Connector* createConnection(
-      const char* ipaddr,
+      const std::string& address,
       std::chrono::microseconds waitSeconds = DEFAULT_CONNECT_TIMEOUT,
       int32_t maxBuffSizePool = 0);
 
